==> qtjambi-qt3dinput-debuginfo-macos-5.15.20.jar: sources/QtJambi3DInput/QKeyEvent_shell.h <==
#ifndef QKEYEVENT_SHELL_H
#define QKEYEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <Qt3DInput/qkeyevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qevent.h>
#include <QtGui/qkeysequence.h>
#include <QtJambi/RegistryAPI>


class QKeyEvent_shell : public Qt3DInput::QKeyEvent, public QtJambiShellInterface
{
public:
    QKeyEvent_shell(QEvent::Type type0, int key1, Qt::KeyboardModifiers modifiers2, const QString& text3 = QString(), bool autorep4 = false, ushort count5 = 1);
    QKeyEvent_shell(const ::QKeyEvent& ke0);
    ~QKeyEvent_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QKeyEvent_access : public Qt3DInput::QKeyEvent
{
};

#endif // QKEYEVENT_SHELL_H

==> qtjambi-qt3dinput-debuginfo-macos-6.5.4.jar: sources/QtJambi3DInput/QKeyEvent_shell.h <==
#ifndef QKEYEVENT_SHELL_H
#define QKEYEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <Qt3DInput/qkeyevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qevent.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtJambi/RegistryAPI>


class QKeyEvent_shell : public Qt3DInput::QKeyEvent, public QtJambiShellInterface
{
public:
    QKeyEvent_shell(QEvent::Type type0, int key1, Qt::KeyboardModifiers modifiers2, const QString& text3 = QString(), bool autorep4 = false, ushort count5 = 1);
    QKeyEvent_shell(const ::QKeyEvent& ke0);
    ~QKeyEvent_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QKeyEvent_access : public Qt3DInput::QKeyEvent
{
};

#endif // QKEYEVENT_SHELL_H
